@@ -48,15 +48,13 @@ async def main():
 
 
 if __name__ == "__main__":
-    loop = asyncio.get_event_loop()
     try:
-        loop.run_until_complete(main())
+        asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())
+        asyncio.run(main())
 
     except KeyboardInterrupt:
         pass
 
     except Exception as e:
         send_message(f"Skyhub: {e}")
-    
-    finally:
-        loop.close()
+
