@@ -1,5 +1,3 @@
 from .produto_model import Produto
 
-__all__ = [
-    "Produto"
-]
+__all__ = ["Produto"]
